unit ScriptingBridge;

{
  Minimal single-file unit. For complete ScriptingBridge parsed headers:
    https://github.com/genericptr

  See also Apple's docs:
    https://developer.apple.com/documentation/scriptingbridge?language=objc

    https://developer.apple.com/library/content/documentation/Cocoa/Conceptual/
     ScriptingBridgeConcepts/Introduction/Introduction.html
}

{$mode delphi}
{$modeswitch objectivec1}

{$linkframework ScriptingBridge}

interface

uses
  CTypes,
{$IFDEF NoCocoaAll}
  Foundation;
{$ELSE}
  CocoaAll;
{$ENDIF}

type
   //from SBElementArray.inc  //note SBElementArray<ObjectType> in 10.11
  SBElementArray = objcclass external (NSMutableArray)
  public
    function objectWithName (name: NSString): id; message 'objectWithName:';
    function objectWithID (identifier: id): id; message 'objectWithID:';
    function objectAtLocation (location: id): id; message 'objectAtLocation:';
    function arrayByApplyingSelector (selector: SEL): NSArray; message 'arrayByApplyingSelector:';
    function arrayByApplyingSelector_withObject (aSelector: SEL; argument: id): NSArray; message 'arrayByApplyingSelector:withObject:';
    function get: NSArray; message 'get';
  end;


   //from SBObject.inc
  SBObject = objcclass external (NSObject, NSCodingProtocol)
    function init: id; message 'init';
    function initWithProperties (properties: NSDictionary): id; message 'initWithProperties:';
    function initWithData (data: id): id; message 'initWithData:';
    function lastError: NSError; message 'lastError';
    function get: id; message 'get';
    { Adopted protocols }
    procedure encodeWithCoder (aCoder: NSCoder); message 'encodeWithCoder:';
    function initWithCoder (aDecoder: NSCoder): id; message 'initWithCoder:';
  end;

  FourCharCode = UInt32;
  ResType = FourCharCode;
  DescType = ResType;

  SBGlueInterface = objccategory external (SBObject)
    function initWithElementCode_properties_data (code: DescType; properties: NSDictionary; data: id): id; message 'initWithElementCode:properties:data:';
//    function propertyWithCode (code: AEKeyword): SBObject; message 'propertyWithCode:';
//    function propertyWithClass_code (cls: pobjc_class; code: AEKeyword): SBObject; message 'propertyWithClass:code:';
//    function elementArrayWithCode (code: DescType): SBElementArray; message 'elementArrayWithCode:';
//    function sendEvent_id_parameters (eventClass: AEEventClass; eventID: AEEventID; firstParamCode: DescType): id; varargs; message 'sendEvent:id:parameters:';
    procedure setTo (value: id); message 'setTo:';
  end;


   //from SBApplication.inc
  SBApplicationDelegateProtocol = objcprotocol external name 'SBApplicationDelegate'
//    function eventDidFail_withError (event: AppleEventPtr; error: NSError): id; message 'eventDidFail:withError:';
  end;

  SBApplication = objcclass external (SBObject, NSCodingProtocol)
  public
    class function applicationWithBundleIdentifier (ident: NSString): id; message 'applicationWithBundleIdentifier:';
    function classForScriptingClass (className: NSString): pobjc_class; message 'classForScriptingClass:';
    function isRunning: boolean; message 'isRunning';
    procedure activate; message 'activate';
    procedure setDelegate(newValue: SBApplicationDelegateProtocol); message 'setDelegate:';
    function delegate: SBApplicationDelegateProtocol; message 'delegate';
  end;


implementation

end.
