program TestScriptFile;

{$mode objfpc}{$H+}
{$modeswitch objectivec2}

uses
  SysUtils,
{$IFDEF NoCocoaAll}
  Foundation;
{$ELSE}
  CocoaAll;
{$ENDIF}

function RunScript(const ScriptFName : string;
                     out ErrorMsg    : string) : Boolean;
var
  ScriptURL : NSURL;
  ScriptObj : NSAppleScript;
  ErrorInfo : NSDictionary;
  EventDesc : NSAppleEventDescriptor;

begin
  Result := False;
  ErrorMsg := '';

  if (Copy(ScriptFName, 1, 5) = 'http:') or
     (Copy(ScriptFName, 1, 6) = 'https:') then
    ScriptURL := NSURL.URLWithString(NSSTR(PAnsiChar(ScriptFName)))
  else
    ScriptURL := NSURL.fileURLWithPath(NSSTR(PAnsiChar(ScriptFName)));

  ScriptObj := NSAppleScript.alloc.initWithContentsOfURL_error(
                ScriptURL, @ErrorInfo);
  if not Assigned(ScriptObj) then
    begin
    ErrorMsg := 'Unable to load script:'#10 +
                NSString(ErrorInfo.objectForKey(NSAppleScriptErrorMessage)).UTF8String;
    Exit;
    end;

  try
    EventDesc := ScriptObj.ExecuteAndReturnError(@ErrorInfo);
    if not Assigned(EventDesc) then
      begin
      ErrorMsg := 'Unable to execute script:'#10 +
                  NSString(ErrorInfo.objectForKey(NSAppleScriptErrorMessage)).UTF8String;
      Exit;
      end;
    if (EventDesc.stringValue.UTF8String <> '') and
       (EventDesc.stringValue.UTF8String <> 'true') then
      begin
      ErrorMsg := 'Error executing script:'#10 +
                  EventDesc.stringValue.UTF8String;
      Exit;
      end;

    Result := True;

  finally
    ScriptObj.release;
  end;
end;


var
  ErrorMsg : string;
begin
  if ParamStr(1) = '' then
    begin
    WriteLn('No script file specified.');
    Halt(1);
    end;

  if not RunScript(ParamStr(1), ErrorMsg) then
    begin
    WriteLn(ErrorMsg);
    Halt(1);
    end;
end.
